<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis93000DirfFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function insert($row) {
        $sql = "INSERT INTO 
                  PARAMDECLACES
                    (CDTELA, 
                    CDEMPRESA, 
                    CDINSCRICAO,
                    CDCAMPO1,
                    CDCAMPO2,
                    CDCAMPO3,
                    CDCAMPO4,
                    CDCAMPO5,
                    CDCAMPO6,
                    CDCAMPO7,
                    CDCAMPO8,
                    CDCAMPO9,
                    CDCAMPO10,
                    CDCAMPO11,
                    DTCAMPO1,
                    CDCAMPO12
                    )
                    VALUES
                    ('FIS93000', 
                    :CDEMPRESA,
                    'FEDERAL',
                    :CDTPDECLARACAO,
                    :NUMRECIBO,
                    :CDNATDECLARANTE,
                    :CDINDSOCIO,
                    :CDDEPOSITCRED,
                    :CDTPINVEST,
                    :CDRENDPGEXT,
                    :CDINDPLANSD,
                    :CDPGIMUISE,
                    :CDFUNPUBDIRPRIV,
                    :CDSITESP,
                    :DTEVENTO,
                    :CDREPRES
                    )";
                
        $params = array(
            "NRORG"         => $row["NRORG"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCRICAO"    => $row["CDINSCRICAO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            
            "CDCAMPO1"  => $row["CDTPDECLARACAO"],
            "CDCAMPO2"  => $row["NUMRECIBO"],
            "CDCAMPO3"  => $row["CDNATDECLARANTE"],
            "CDCAMPO4"  => $row["CDINDSOCIO"],
            "CDCAMPO5"  => $row["CDDEPOSITCRED"],
            "CDCAMPO6"  => $row["CDTPINVEST"],
            "CDCAMPO7"  => $row["CDRENDPGEXT"],
            "CDCAMPO8"  => $row["CDINDPLANSD"],
            "CDCAMPO9"  => $row["CDPGIMUISE"],
            "CDCAMPO10"  => $row["CDFUNPUBDIRPRIV"],
            "CDCAMPO11"  => $row["CDFUNPUBCDSITESPDIRPRIV"],
            "CDCAMPO12"  => $row["CDREPRES"],
            "DTCAMPO1"=>$row["DTEVENTO"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function update($row) {
        $sql = "UPDATE PARAMDECLACES
                    SET CDEMPRESA = :CDEMPRESA,
                        CDINSCRICAO = :CDINSCRICAO,
                    	DTINICIAL = :DTINICIAL,
                    	DTFINAL = :DTFINAL,
                    	CDCAMPO1 = :CDCAMPO1,
                        CDCAMPO2 = :CDCAMPO2,
                        CDCAMPO3 = :CDCAMPO3,
                        CDCAMPO4 = :CDCAMPO4,
                        CDCAMPO5 = :CDCAMPO5,
                        CDCAMPO6 = :CDCAMPO6,
                        CDCAMPO7 = :CDCAMPO7,
                        CDCAMPO8 = :CDCAMPO8,
                        CDCAMPO9 = :CDCAMPO9,
                        CDCAMPO10 = :CDCAMPO10,
                        CDCAMPO11 = :CDCAMPO11,
                        CDCAMPO12 = :CDCAMPO12,
                        DTCAMPO1 = :DTCAMPO1
                    WHERE CDTELA = :CDTELA";
                    
        $params = array(
            "NRORG"         => $row["NRORG"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCRICAO"    => $row["CDINSCRICAO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            
            "CDCAMPO1"  => $row["CDTPDECLARACAO"],
            "CDCAMPO2"  => $row["NUMRECIBO"],
            "CDCAMPO3"  => $row["CDNATDECLARANTE"],
            "CDCAMPO4"  => $row["CDINDSOCIO"],
            "CDCAMPO5"  => $row["CDDEPOSITCRED"],
            "CDCAMPO6"  => $row["CDTPINVEST"],
            "CDCAMPO7"  => $row["CDRENDPGEXT"],
            "CDCAMPO8"  => $row["CDINDPLANSD"],
            "CDCAMPO9"  => $row["CDPGIMUISE"],
            "CDCAMPO10"  => $row["CDFUNPUBDIRPRIV"],
            "CDCAMPO11"  => $row["CDFUNPUBCDSITESPDIRPRIV"],
            "CDCAMPO12"  => $row["CDREPRES"],
            "DTCAMPO1"=>$row["DTEVENTO"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    public function callExportacaoProcedure($params) {
        set_time_limit(18000);
        $procedure = new StoredProcedure($this->connection, 'ARQUIVO_DIRF');
        $fieldNames = array_keys($params);
        foreach($fieldNames as $fieldName){
             $procedure->addParam(new Param(('P_'.$fieldName), Param::PARAM_INPUT, $params[$fieldName], Param::PARAM_TYPE_STR));
        }
        $procedure->execute();
        
        
    }
    
        /*
     * Função para retornar os dados gerados na procedure da GIA - ICMS - ST.
     */
    public function getdirf($params) {
        // Query a ser executada.
        $sql = "SELECT P.CDEMPRESA, P.CDINSCRICAO, P.CDTELA, P.NRORG, P.CDCAMPO1  AS CDTPDECLARACAO, P.CDCAMPO2  AS NUMRECIBO, P.CDCAMPO3  AS CDNATDECLARANTE, P.CDCAMPO4  AS CDINDSOCIO, P.CDCAMPO5  AS CDDEPOSITCRED, P.CDCAMPO6  AS CDTPINVEST, P.CDCAMPO7  AS CDRENDPGEXT, P.CDCAMPO8  AS CDINDPLANSD, P.CDCAMPO9  AS CDPGIMUISE, P.CDCAMPO10 AS CDFUNPUBDIRPRIV, P.CDCAMPO11 AS CDSITESP, P.DTCAMPO1  AS DTEVENTO, P.CDCAMPO12 AS CDREPRES, R.NMREPRES FROM PARAMDECLACES P, REPRESLEGAL R WHERE P.CDTELA    = 'FIS93000' AND P.CDEMPRESA   = :P_CDEMPRESA AND P.CDINSCRICAO = 'FEDERAL' AND P.NRORG       =:NRORG AND P.CDCAMPO12   = R.CDREPRES(+)";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }
    
    
}
